package java.security;

import java.security.spec.AlgorithmParameterSpec;

public class AlgorithmParameterGenerator
{
    private Provider provider;
    private AlgorithmParameterGeneratorSpi paramGenSpi;
    private String algorithm;
    
    protected AlgorithmParameterGenerator(AlgorithmParameterGeneratorSpi paramGenSpi, Provider provider, String algorithm) {
        this.paramGenSpi = paramGenSpi;
        this.provider = provider;
        this.algorithm = algorithm;
    }
    
    public final String getAlgorithm() {
        return this.algorithm;
    }
    
    public static AlgorithmParameterGenerator getInstance(String str) throws NoSuchAlgorithmException {
        try {
            Object[] impl = Security.getImpl(str, "AlgorithmParameterGenerator", (String)null);
            return new AlgorithmParameterGenerator((AlgorithmParameterGeneratorSpi)impl[0], (Provider)impl[1], str);
        }
        catch (NoSuchProviderException ex) {
            throw new NoSuchAlgorithmException(str + " not found");
        }
    }
    
    public static AlgorithmParameterGenerator getInstance(String s, String s2) throws NoSuchAlgorithmException, NoSuchProviderException {
        if (s2 == null || s2.length() == 0) {
            throw new IllegalArgumentException("missing provider");
        }
        Object[] impl = Security.getImpl(s, "AlgorithmParameterGenerator", s2);
        return new AlgorithmParameterGenerator((AlgorithmParameterGeneratorSpi)impl[0], (Provider)impl[1], s);
    }
    
    public static AlgorithmParameterGenerator getInstance(String s, Provider provider) throws NoSuchAlgorithmException {
        if (provider == null) {
            throw new IllegalArgumentException("missing provider");
        }
        Object[] impl = Security.getImpl(s, "AlgorithmParameterGenerator", provider);
        return new AlgorithmParameterGenerator((AlgorithmParameterGeneratorSpi)impl[0], (Provider)impl[1], s);
    }
    
    public final Provider getProvider() {
        return this.provider;
    }
    
    public final void init(int n) {
        this.paramGenSpi.engineInit(n, new SecureRandom());
    }
    
    public final void init(int n, SecureRandom secureRandom) {
        this.paramGenSpi.engineInit(n, secureRandom);
    }
    
    public final void init(AlgorithmParameterSpec algorithmParameterSpec) throws InvalidAlgorithmParameterException {
        this.paramGenSpi.engineInit(algorithmParameterSpec, new SecureRandom());
    }
    
    public final void init(AlgorithmParameterSpec algorithmParameterSpec, SecureRandom secureRandom) throws InvalidAlgorithmParameterException {
        this.paramGenSpi.engineInit(algorithmParameterSpec, secureRandom);
    }
    
    public final AlgorithmParameters generateParameters() {
        return this.paramGenSpi.engineGenerateParameters();
    }
}
